"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const crypto_1 = require("@arkecosystem/crypto");
const command_1 = require("@oclif/command");
const utils_1 = require("../utils");
const command_2 = require("./command");
class IdentityCommand extends command_2.BaseCommand {
    async run() {
        // tslint:disable-next-line:no-shadowed-variable
        const { flags } = this.parse(IdentityCommand);
        let output;
        if (flags.type === "passphrase") {
            const keys = crypto_1.crypto.getKeys(flags.data);
            output = {
                passphrase: flags.data,
                publicKey: keys.publicKey,
                privateKey: keys.privateKey,
                address: crypto_1.crypto.getAddress(keys.publicKey, flags.network),
            };
        }
        else if (flags.type === "privateKey") {
            const keys = crypto_1.crypto.getKeysByPrivateKey(flags.data);
            output = {
                publicKey: keys.publicKey,
                privateKey: keys.privateKey,
                address: crypto_1.crypto.getAddress(keys.publicKey, flags.network),
            };
        }
        else if (flags.type === "publicKey") {
            output = {
                publicKey: flags.data,
                address: crypto_1.crypto.getAddress(flags.data, flags.network),
            };
        }
        return utils_1.handleOutput(flags, output);
    }
}
IdentityCommand.description = "Get identities from the given input";
IdentityCommand.flags = Object.assign({}, command_2.BaseCommand.flags, { data: command_1.flags.string({
        description: "the data to get the identities from",
        required: true,
    }), network: command_1.flags.integer({
        description: "the network version used for calculating the address.",
        required: true,
        default: 30,
    }), type: command_1.flags.string({
        description: "the input type is either of passphrase, privateKey or publicKey",
        required: true,
    }) });
exports.IdentityCommand = IdentityCommand;
//# sourceMappingURL=identity.js.map